==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/SELinuxOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SELinuxOptionsFluent<A extends io.fabric8.kubernetes.api.model.SELinuxOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getLevel();
  public A withLevel(java.lang.String level);
  public java.lang.Boolean hasLevel();
  
  /**
   * Method is deprecated. use withLevel instead.
   */
  @java.lang.Deprecated
  public A withNewLevel(java.lang.String arg0);
  public java.lang.String getRole();
  public A withRole(java.lang.String role);
  public java.lang.Boolean hasRole();
  
  /**
   * Method is deprecated. use withRole instead.
   */
  @java.lang.Deprecated
  public A withNewRole(java.lang.String arg0);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public java.lang.String getUser();
  public A withUser(java.lang.String user);
  public java.lang.Boolean hasUser();
  
  /**
   * Method is deprecated. use withUser instead.
   */
  @java.lang.Deprecated
  public A withNewUser(java.lang.String arg0);
  
}

==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/SELinuxOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SELinuxOptionsFluent<A extends io.fabric8.kubernetes.api.model.SELinuxOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getLevel();
  public A withLevel(java.lang.String level);
  public java.lang.Boolean hasLevel();
  
  /**
   * Method is deprecated. use withLevel instead.
   */
  @java.lang.Deprecated
  public A withNewLevel(java.lang.String arg0);
  public java.lang.String getRole();
  public A withRole(java.lang.String role);
  public java.lang.Boolean hasRole();
  
  /**
   * Method is deprecated. use withRole instead.
   */
  @java.lang.Deprecated
  public A withNewRole(java.lang.String arg0);
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public java.lang.String getUser();
  public A withUser(java.lang.String user);
  public java.lang.Boolean hasUser();
  
  /**
   * Method is deprecated. use withUser instead.
   */
  @java.lang.Deprecated
  public A withNewUser(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
